// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#ifndef RIEGELI_BASE_UNICODE_H_
#define RIEGELI_BASE_UNICODE_H_

#ifdef _WIN32

#include <string>

#include "absl/strings/string_view.h"
#include "absl/types/span.h"

namespace riegeli {

// Converts from UTF-8 string to `wchar_t[]`.
//
// Returns `false` on failure.
bool Utf8ToWide(absl::string_view src, std::wstring& dest);

// Converts from `wchar_t[]` to UTF-8 string.
//
// Returns `false` on failure.
bool WideToUtf8(absl::Span<const wchar_t> src, std::string& dest);

// Converts from `wchar_t[]` to UTF-8 string.
//
// Emits replacement characters on failure.
std::string WideToUtf8Lossy(absl::Span<const wchar_t> src);

}  // namespace riegeli

#endif

#endif  // RIEGELI_BASE_UNICODE_H_
